summaryrefslogtreecommitdiffstats
path: root/src/notedrag.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-17 08:20:48 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-05-17 08:20:48 +0000
commitaa0726b20f398264f0a2abc60215be044b106f9c (patch)
tree070fdbc19a1106cfdd7f651a8ce76bb1b89a513d /src/notedrag.h
parentd3cf5b3e75aadc3b02d0b56f030d4c3f8c2c749d (diff)
downloadbasket-aa0726b20f398264f0a2abc60215be044b106f9c.tar.gz
basket-aa0726b20f398264f0a2abc60215be044b106f9c.zip
TQt4 port basket
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/applications/basket@1232416 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'src/notedrag.h')
-rw-r--r--src/notedrag.h44
1 files changed, 23 insertions, 21 deletions
diff --git a/src/notedrag.h b/src/notedrag.h
index 6dd9c62..3482c01 100644
--- a/src/notedrag.h
+++ b/src/notedrag.h
@@ -21,14 +21,14 @@
#ifndef NOTEDRAG_H
#define NOTEDRAG_H
-#include <qstring.h>
-#include <qdragobject.h>
-#include <qdatastream.h>
-#include <qpixmap.h>
-#include <qvaluelist.h>
+#include <tqstring.h>
+#include <tqdragobject.h>
+#include <tqdatastream.h>
+#include <tqpixmap.h>
+#include <tqvaluelist.h>
#include <kmultipledrag.h>
-class QDataStream;
+class TQDataStream;
class Basket;
class Note;
@@ -54,49 +54,51 @@ class NoteSelection;
class NoteDrag
{
protected:
- static void serializeNotes( NoteSelection *noteList, QDataStream &stream, bool cutting );
+ static void serializeNotes( NoteSelection *noteList, TQDataStream &stream, bool cutting );
static void serializeText( NoteSelection *noteList, KMultipleDrag *multipleDrag );
static void serializeHtml( NoteSelection *noteList, KMultipleDrag *multipleDrag );
static void serializeImage( NoteSelection *noteList, KMultipleDrag *multipleDrag );
static void serializeLinks( NoteSelection *noteList, KMultipleDrag *multipleDrag, bool cutting );
static void setFeedbackPixmap( NoteSelection *noteList, KMultipleDrag *multipleDrag );
- static Note* decodeHierarchy(QDataStream &stream, Basket *parent, bool moveFiles, bool moveNotes, Basket *originalBasket);
+ static Note* decodeHierarchy(TQDataStream &stream, Basket *tqparent, bool moveFiles, bool moveNotes, Basket *originalBasket);
public:
- static QPixmap feedbackPixmap(NoteSelection *noteList);
- static QDragObject* dragObject(NoteSelection *noteList, bool cutting, QWidget *source = 0);
- static bool canDecode(QMimeSource *source);
- static Note* decode(QMimeSource *source, Basket *parent, bool moveFiles, bool moveNotes);
- static Basket* basketOf(QMimeSource *source);
- static QValueList<Note*> notesOf(QMimeSource *source);
+ static TQPixmap feedbackPixmap(NoteSelection *noteList);
+ static TQDragObject* dragObject(NoteSelection *noteList, bool cutting, TQWidget *source = 0);
+ static bool canDecode(TQMimeSource *source);
+ static Note* decode(TQMimeSource *source, Basket *tqparent, bool moveFiles, bool moveNotes);
+ static Basket* basketOf(TQMimeSource *source);
+ static TQValueList<Note*> notesOf(TQMimeSource *source);
static void createAndEmptyCuttingTmpFolder();
static const char *NOTE_MIME_STRING;
};
/** QTextDrag with capabilities to drop GNOME and Mozilla texts
* as well as UTF-16 texts even if it was supposed to be encoded
* with local encoding!
* @author Sébastien Laoût
*/
-class ExtendedTextDrag : public QTextDrag
+class ExtendedTextDrag : public TQTextDrag
{
Q_OBJECT
+ TQ_OBJECT
public:
- static bool decode(const QMimeSource *e, QString &str);
- static bool decode(const QMimeSource *e, QString &str, QCString &subtype);
+ static bool decode(const TQMimeSource *e, TQString &str);
+ static bool decode(const TQMimeSource *e, TQString &str, TQCString &subtype);
};
// Support KDE 3.3 and older PROTECTED KURLDrag::encodedData()!
#include <kurldrag.h>
class KURLDrag2 : public KURLDrag
{
Q_OBJECT
+ TQ_OBJECT
public:
KURLDrag2(const KURL::List &urls) : KURLDrag(urls) {}
- QByteArray encodedData2(const char *mime) const
+ TQByteArray tqencodedData2(const char *mime) const
{
- return encodedData(mime);
+ return tqencodedData(mime);
}
};
@@ -54,49 +54,51 @@ class NoteSelection;
static const char *NOTE_MIME_STRING;
};
-/** QTextDrag with capabilities to drop GNOME and Mozilla texts
+/** TQTextDrag with capabilities to drop GNOME and Mozilla texts
* as well as UTF-16 texts even if it was supposed to be encoded
* with local encoding!
@@ -54,49 +54,51 @@ class NoteSelection;
};
-// Support KDE 3.3 and older PROTECTED KURLDrag::encodedData()!
+// Support KDE 3.3 and older PROTECTED KURLDrag::tqencodedData()!
#include <kurldrag.h>
class KURLDrag2 : public KURLDrag